@@ -34,31 +34,41 @@ def main(
 ):
     """Springer Textbook Bulk Download Tool
     
-    NOTICE:
+    **NOTICE**:
 
     Author not affiliated with Springer and this tool is not authorized
     or supported by Springer. Thank you to Springer for making these
     high quality textbooks available at no cost. 
 
-    From `https://www.springernature.com/gp/librarians/news-events/all-news-articles/industry-news-initiatives/free-access-to-textbooks-for-institutions-affected-by-coronaviru/17855960`:
-
-    "With the Coronavirus outbreak having an unpretextbookscedented
-    impact on education, Springer Nature is launching a global program
-    to support learning and teaching at higher education institutions
-    worldwide. Remote access to educational resources has become
-    essential. We want to support lecturers, teachers and students
-    during this challenging period and hope that this initiative will go
-    some way to help. 
-
-    Institutions will be able to access more than 500 key textbooks
-    across Springer Nature’s eBook subject collections for free. In
-    addition, we are making a number of German-language Springer medical
-    training books on emergency nursing freely accessible.  These books
-    will be available via SpringerLink until at least the end of July."
+    \b
+    >"With the Coronavirus outbreak having an unprecedented impact on
+    >education, Springer Nature is launching a global program to support
+    >learning and teaching at higher education institutions
+    >worldwide. Remote access to educational resources has become
+    >essential. We want to support lecturers, teachers and students
+    >during this challenging period and hope that this initiative will go
+    >some way to help.
+    >
+    >Institutions will be able to access more than 500 key textbooks
+    >across Springer Nature’s eBook subject collections for free. In
+    >addition, we are making a number of German-language Springer medical
+    >training books on emergency nursing freely accessible.  These books
+    >will be available via SpringerLink until at least the end of July."
 
+    [Source](https://www.springernature.com/gp/librarians/news-events/all-news-articles/industry-news-initiatives/free-access-to-textbooks-for-institutions-affected-by-coronaviru/17855960)
+    
     This tool automates the tasks of downloading the Excel-formatted
     catalogs and downloading the files described in the catalog.
 
+    This utility can be installed using `pip`:
+
+    `$ python3 -m pip install springer`
+
+    Or the latest from master:
+
+    `$ python3 -m pip install git+https://github.com/JnyJny/springer_downloader`
+
+    The source is available on [GitHub](https://github.com/JnyJny/springer_downloader).
     """
 
     # EJO The callback function is called before any of the command functions
@@ -80,8 +90,8 @@ def list(
     file_format: FileFormat = typer.Option(
         FileFormat.pdf, "--format", "-f", show_default=True, show_choices=True
     ),
-    show_path: bool = typer.Option(
-        False, "--show-path", "-p", help="Show generated filename for each book.",
+    long_format: bool = typer.Option(
+        False, "--long-format", "-l", help="Show more information for each book.",
     ),
 ):
     """List titles of textbooks in the catalog.
@@ -90,15 +100,23 @@ def list(
     
     List titles available in the default catalog (en-all):
 
-    $ springer list
+    `$ springer list`
 
     List titles available in the German language, all disciplines catalog:
 
-    $ springer --language de --category all list
+    `$ springer --language de --category all list`
 
     """
 
-    ctx.obj.list(file_format, show_path=show_path)
+    for index, textbook in enumerate(ctx.obj.textbooks(file_format), start=1):
+        print(f"  Title #{index:03d}: ", textbook.title)
+        if long_format:
+            print("        Path> ", textbook.path)
+            print("      Author> ", textbook.author)
+            print("     Edition> ", textbook.edition)
+            print("        ISBN> ", textbook.isbn)
+            print("       EISBN> ", textbook.eisbn)
+            print("     DOI URL> ", textbook.doi_url)
 
 
 @cli.command()
@@ -155,27 +173,27 @@ def download(
 
     Download all books in PDF format to the current directory:
     
-    $ springer download
+    `$ springer download`
     
     Download all books in EPUB format to the current directory:
 
-    $ springer download --format epub
+    `$ springer download --format epub`
 
     Download all books in PDF format to a directory `pdfs`:
 
-    $ springer download --dest-path pdfs
+    `$ springer download --dest-path pdfs`
 
     Download books in PDF format to `pdfs` with overwriting:
 
-    $ springer download --dest-path pdfs --over-write
+    `$ springer download --dest-path pdfs --over-write`
 
     Download all books in PDF from the German all disciplines catalog:
     
-    $ springer -L de -C all download --dest-path german/all/pdfs
+    `$ springer -L de -C all download --dest-path german/all/pdfs`
 
     Download all books from all catelogs in epub format:
 
-    $ springer download --all --dest-path books --format epub
+    `$ springer download --all --dest-path books --format epub`
     """
 
     logger.configure(
@@ -220,19 +238,19 @@ def refresh(
 
     Update English language catalog:
 
-    $ springer --language en refresh
+    `$ springer --language en refresh`
 
     Update German language catalog whose category is 'all':
 
-    $ springer --language de --category all refresh
+    `$ springer --language de --category all refresh`
 
     Update German language catalog whose category is 'med' with a new URL:
 
-    $ springer -L de -C med refresh --url https://example.com/api/endpoint/something/v11
+    `$ springer -L de -C med refresh --url https://example.com/api/endpoint/something/v11`
 
     Update all catalogs:
 
-    $ springer refresh --all
+    `$ springer refresh --all`
 
     """
 
@@ -258,6 +276,16 @@ def clean(
     all_catalogs: bool = typer.Option(False, "--all", is_flag=True),
 ):
     """Removes the cached catalog.
+
+    Examples
+
+    Remove the English language, all disciplines cached catalog:
+
+    `$ springer clean -F`
+
+    Remove the German language emergency nursing cached catalog:
+
+    `$ springer -L de -C med clean -F`
     """
 
     if not force:
@@ -277,8 +305,18 @@ def clean(
 
 
 @cli.command()
-def catalogs(ctx: typer.Context):
+def catalogs():
     """List available catalogs.
+
+    Prints an entry for each known catalog:
+    
+    \b
+    - Catalog URL
+    - Language
+    - Category
+    - Cache file path
+    - Number of books in the catalog.
+
     """
 
     for language in Language:
